@@ -541,8 +541,11 @@ sub sort_func
 	my $i = -1;
 	# tested example sortcode:
 	# '{ my $c; ($c= $a->[0] <=> $b->[0]) ? $c : ($c= $a->[1] <=> $b->[1]) ? $c : 0 }'
-	foreach my $c (@{$cols})
+	foreach my $prec (@{$cols})
 	{
+		# Ensure only integer values enter evalued code.
+		# Invalid numbers get parsed to zero, as perl does normally.
+		my $c = $prec =~ /^(\d+)/ ? $1 : 0;
 		my $r = '$r';
 		my $a = '$a';
 		my $b = '$b';
